@@ -35,8 +35,6 @@ import logging
 import os
 import sys
 
-LOG = logging.getLogger(__name__)
-
 if __name__ == '__main__':
     # Only useful for when running directly (for dev/debugging).
     sys.path.insert(0, os.path.abspath(os.getcwd()))
@@ -49,6 +47,7 @@ from stevedore import extension
 from doc8 import checks
 from doc8 import parser as file_parser
 from doc8 import utils
+from doc8 import version
 
 FILE_PATTERNS = ['.rst', '.txt']
 MAX_LINE_LENGTH = 79
@@ -92,6 +91,11 @@ def extract_config(args):
         cfg['ignore'] = split_set_type(parser.get("doc8", "ignore"))
     except (configparser.NoSectionError, configparser.NoOptionError):
         pass
+    try:
+        cfg['ignore_path'] = split_set_type(parser.get("doc8",
+                                                       "ignore_path"))
+    except (configparser.NoSectionError, configparser.NoOptionError):
+        pass
     try:
         cfg['allow_long_titles'] = parser.getboolean("doc8",
                                                      "allow-long-titles")
@@ -169,8 +173,8 @@ def main():
                         help="do not ignore sphinx specific false positives",
                         default=True, dest='sphinx')
     parser.add_argument("--ignore-path", action="append", default=[],
-                        help="ignore the given directory or file",
-                        metavar='path')
+                        help="ignore the given directory or file (globs"
+                             " are supported)", metavar='path')
     parser.add_argument("--max-line-length", action="store", metavar="int",
                         type=int,
                         help="maximum allowed line"
@@ -183,26 +187,41 @@ def main():
                         default=[])
     parser.add_argument("-v", "--verbose", dest="verbose", action='store_true',
                         help="run in verbose mode", default=False)
+    parser.add_argument("--version", dest="version", action='store_true',
+                        help="show the version and exit", default=False)
     args = vars(parser.parse_args())
+    if args.get('version'):
+        print(version.version_string())
+        return 0
     args['ignore'] = merge_sets(args['ignore'])
     cfg = extract_config(args)
     args['ignore'].update(cfg.pop("ignore", set()))
     if 'sphinx' in cfg:
         args['sphinx'] = cfg.pop("sphinx")
     args['extension'].extend(cfg.pop('extension', []))
+    args['ignore_path'].extend(cfg.pop('ignore_path', []))
     args.update(cfg)
     if not args.get('extension'):
         args['extension'] = list(FILE_PATTERNS)
     setup_logging(args.get('verbose'))
-    files = collections.deque()
-    ignored_paths = []
-    for path in args.pop('ignore_path', []):
-        ignored_paths.append(os.path.normpath(path))
+
     print("Scanning...")
-    for filename in utils.find_files(args.pop('paths', []),
-                                     args.pop('extension', []),
-                                     ignored_paths):
-        files.append(file_parser.parse(filename))
+    files = collections.deque()
+    ignored_paths = args.pop('ignore_path')
+    files_ignored = 0
+    files_selected = 0
+    file_iter = utils.find_files(args.pop('paths', []),
+                                 args.pop('extension', []), ignored_paths)
+    for filename, ignoreable in file_iter:
+        if ignoreable:
+            files_ignored += 1
+            if args.get('verbose'):
+                print("  Ignoring '%s'" % (filename))
+        else:
+            files_selected += 1
+            files.append(file_parser.parse(filename))
+            if args.get('verbose'):
+                print("  Selecting '%s'" % (filename))
 
     ignoreables = frozenset(args.pop('ignore', []))
     error_counts = {}
@@ -217,9 +236,17 @@ def main():
             except AttributeError:
                 check_name = ".".join([c.__class__.__module__,
                                        c.__class__.__name__])
-            if args.get('verbose'):
-                print("  Running check '%s'" % check_name)
             error_counts.setdefault(check_name, 0)
+            try:
+                extension_matcher = c.EXT_MATCHER
+            except AttributeError:
+                pass
+            else:
+                if not extension_matcher.match(f.extension):
+                    print("  Skipping check '%s' since it does not understand"
+                          " parsing a file with extension '%s'"
+                          % (check_name, f.extension))
+                    continue
             try:
                 reports = set(c.REPORTS)
             except AttributeError:
@@ -227,9 +254,12 @@ def main():
             else:
                 reports = reports - ignoreables
                 if not reports:
-                    LOG.debug("Skipping check '%s', determined to only"
-                              " check ignoreable codes", check_name)
+                    if args.get('verbose'):
+                        print("  Skipping check '%s', determined to only"
+                              " check ignoreable codes" % check_name)
                     continue
+            if args.get('verbose'):
+                print("  Running check '%s'" % check_name)
             if isinstance(c, checks.ContentCheck):
                 for line_num, code, message in c.report_iter(f):
                     if code in ignoreables:
@@ -258,6 +288,8 @@ def main():
                                 % (type(c), c))
     total_errors = sum(six.itervalues(error_counts))
     print("=" * 8)
+    print("Total files scanned = %s" % (files_selected))
+    print("Total files ignored = %s" % (files_ignored))
     print("Total accumulated errors = %s" % total_errors)
     if error_counts:
         print("Detailed error counts:")
